==> haskell-dns-2.0.1-8-armv7h.pkg.tar.xz: usr/share/haskell/haskell-dns/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.1
id: dns-2.0.1-802909597b419bc5fd8ba6ac86d5c572
key: dns_DwIkcIN5rkkDUaGle5qoix
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Lookup Network.DNS.Resolver
    Network.DNS.Utils Network.DNS.Types Network.DNS.Encode
    Network.DNS.Decode
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/dns-2.0.1
hs-libraries: HSdns-2.0.1-DwIkcIN5rkkDUaGle5qoix
depends:
    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.1-20c379c1e33e978c5d5c8f5ef78dd0c3
    conduit-extra-1.1.9.2-aa4a80a63306500e6d6a1edce4badfdd
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    resourcet-1.1.7.1-34b9e931a3d19e984bea5de562a18bbd
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dns-2.0.1-13-armv7h.pkg.tar.xz: usr/share/haskell/haskell-dns/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.1
id: dns-2.0.1-1bad62ddd13b6e401daf614b50d049c4
key: dns_K29PvNogtzD6wdJWxse4C0
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Lookup Network.DNS.Resolver
    Network.DNS.Utils Network.DNS.Types Network.DNS.Encode
    Network.DNS.Decode
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/dns-2.0.1
hs-libraries: HSdns-2.0.1-K29PvNogtzD6wdJWxse4C0
depends:
    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
    conduit-extra-1.1.11-b294a7608a3a066998e74974ec65ff9b
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
